%define commit 684af0548ed76fd97635687fa90a754a7a04a017
%define shortcommit %(c=%{commit}; echo ${c:0:7})

%define build_cinepaint 0
%{?_with_cinepaint: %global build_cinepaint 1}

%if %{build_cinepaint}
%define cinepaint_dir %(pkg-config --variable=programplugindir cinepaint-gtk)
%endif

%define gimpplugin 1
%define abi_version 2.0

%undefine _hardened_build

Name:           ufraw
Version:        0.22
Release:        %mkrel 28
Summary:        Graphical tool to convert raw images of digital cameras
Group:          Graphics/Photography
License:        GPLv2+
URL:            https://ufraw.sourceforge.net/
Source0:        https://github.com/sergiomb2/ufraw/archive/%{commit}.zip?/%{name}-%{shortcommit}.zip
Source1:        https://raw.githubusercontent.com/sergiomb2/ufraw/02bc2df0c6c2d9d1892bd16a58e319d81e79559d/beautify_style.sh
# we need remove patch for file beautify_style.sh because file is not in ufraw-0.22.tar.gz
Patch0:         ufraw-0.22-exiv2-0.28.patch

BuildRequires:  gettext-devel
BuildRequires:  imagemagick
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(jasper)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(exiv2)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(cfitsio)
BuildRequires:  pkgconfig(lensfun)
BuildRequires:  libgomp-devel
%if %{build_cinepaint}
BuildRequires:  cinepaint-devel
%endif
BuildRequires:  pkgconfig(gtkimageview)
%if %{gimpplugin}
BuildRequires:  pkgconfig(gimp-%{abi_version})
%else
Obsoletes:      gimp-plugin-ufraw < %{version}-%{release}
%endif
Recommends:     ufraw-batch

Provides:       bundled(dcraw) = 9.28

%description
UFRaw is a utility to read and manipulate raw images from digital cameras.
%if %{gimpplugin}
It can be used by itself or as a Gimp plug-in.
%endif
It reads raw images using Dave Coffin's raw conversion utility DCRaw.
And it supports basic color management using Little CMS, allowing
the user to apply color profiles.

Raw images are the data directly read from the CCD of the camera,
without in-camera processing, without lossy JPEG compression, and in
36 or 48 bits color depth (TIFF has 24 bits). Problem of the raw
images is that they are in proprietary, camera-specific formats as
they are exactly what the CCD has captured, and the CCDs on different
cameras are very different. It also contains info about the camera
settings.

%package batch
Summary:        Command-line tool to convert raw images of digital cameras
Group:          Graphics/Photography

%description batch
This is the command-line tool for UFRaw meant for converting multiple images
in a batch.

%if %{gimpplugin}
%package -n gimp-plugin-ufraw
Summary:        Reads the raw image formats of digital cameras into GIMP
Group:          Graphics/Editors and Converters
Requires:       gimp
Provides:       %{name}-gimp = %{version}-%{release}

%description -n gimp-plugin-ufraw
A GIMP plug-in which reads and processes raw images from most digital
cameras. The conversion is done by the dcraw software and so all
cameras supported by dcraw are also supported by this plug-in.

In contrary to the original GIMP plug-in of dcraw this one is much
more comfortable, especially because of the life preview image but
also due to more options.
%endif

%if %build_cinepaint
%package cinepaint
Summary:        Reads the raw image formats of digital cameras into Cinepaint
Group:          Graphics/Editors and Converters
Requires:       cinepaint

%description cinepaint
A Cinepaint plug-in which reads and processes raw images from most digital
cameras. The conversion is done by the dcraw software and so all
cameras supported by dcraw are also supported by this plug-in.
%endif

%prep
%autosetup -p1 -n %{name}-%{commit}

cp %{SOURCE1} .

%build
autoreconf -fi
%configure --enable-mime --enable-jasper
%make_build

%install
%make_install schemasdir=%{_sysconfdir}/gconf/schemas
%find_lang ufraw

install -d %{buildroot}%{_datadir}/icons/{large,mini}

convert icons/ufraw.png -resize 32x32 %{buildroot}%{_iconsdir}/%{name}.png
convert icons/ufraw.png -resize 16x16 %{buildroot}%{_miconsdir}/%{name}.png
cp icons/ufraw.png %{buildroot}%{_liconsdir}/%{name}.png

%define schemas ufraw

%preun
%preun_uninstall_gconf_schemas %{schemas}

%files -f %{name}.lang
%doc README
%{_sysconfdir}/gconf/schemas/ufraw.schemas
%{_bindir}/ufraw
%{_datadir}/appdata/ufraw.appdata.xml
%{_datadir}/applications/ufraw.desktop
%{_datadir}/pixmaps/*.png
%{_iconsdir}/*.png
%{_liconsdir}/*.png
%{_miconsdir}/*.png
%{_mandir}/man1/ufraw.*

%files batch
%{_bindir}/ufraw-batch

%if %{gimpplugin}
%files -n gimp-plugin-ufraw
%{_libdir}/gimp/%{abi_version}/plug-ins/*
%endif

%if %{build_cinepaint}
%files cinepaint
%{cinepaint_dir}/plug-ins/*
%endif


%changelog
* Tue Oct 01 2024 ns80 <ns80> 0.22-28.mga10
+ Revision: 2102290
- build without _hardened_build

* Mon Oct 02 2023 daviddavid <daviddavid> 0.22-27.mga10
+ Revision: 1993154
- add openmandriva patch to fix build with exiv2 >= 0.28
- rebuild for new exiv2 0.28.0

* Tue Feb 07 2023 daviddavid <daviddavid> 0.22-26.mga9
+ Revision: 1939226
- remove old and useless dcraw-gimp2.0 and rawphoto Conflicts

* Sun Feb 05 2023 daviddavid <daviddavid> 0.22-25.mga9
+ Revision: 1938617
- re-enable gimp 2.0 plugin (mga#28914)
- rename as gimp-plugin-ufraw

* Mon Dec 12 2022 ns80 <ns80> 0.22-24.mga9
+ Revision: 1921121
- rebuild for new libtiff

* Sun Dec 04 2022 martinw <martinw> 0.22-23.mga9
+ Revision: 1917536
- rebuild for libcfitsio.so.10

* Tue Nov 01 2022 mrambo3501 <mrambo3501> 0.22-22.mga9
+ Revision: 1901038
- rebuild for new lensfun

* Sat Apr 02 2022 umeabot <umeabot> 0.22-21.mga9
+ Revision: 1840876
- Mageia 9 Mass Rebuild

* Sun Aug 08 2021 luigiwalser <luigiwalser> 0.22-20.mga9
+ Revision: 1740703
- update to git snapshot that supports gcc 11
- rebuild for lensfun

* Mon Jan 18 2021 daviddavid <daviddavid> 0.22-18.mga8
+ Revision: 1672391
- update to git 20201114 with ufraw-gimp: properly send EXIF data to Gimp 2.9
  and later and dcraw updated to 9.28 (mga#28162)

* Fri Jan 01 2021 luigiwalser <luigiwalser> 0.22-17.mga8
+ Revision: 1667497
- obsolete gimp2 plugin
- try rebuilding gimp plugin

* Sun Jul 19 2020 martinw <martinw> 0.22-16.mga8
+ Revision: 1607238
- rebuild for new libcfitsio

* Fri Mar 27 2020 daviddavid <daviddavid> 0.22-15.mga8
+ Revision: 1560897
- rebuild for new cfitsio 3.470

* Fri Mar 06 2020 daviddavid <daviddavid> 0.22-14.mga8
+ Revision: 1554483
- really enable JPEG2000 (libjasper) support

* Fri Mar 06 2020 daviddavid <daviddavid> 0.22-13.mga8
+ Revision: 1554482
- enable JPEG2000 (libjasper) support

* Fri Mar 06 2020 daviddavid <daviddavid> 0.22-12.mga8
+ Revision: 1554478
- backport all upstream fixes in a single patch as of 2019-06-12
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Thu May 16 2019 daviddavid <daviddavid> 0.22-11.mga7
+ Revision: 1397996
- improve exiv2-0.27 patch to fix build with exiv2 0.27.1

* Sun Dec 30 2018 daviddavid <daviddavid> 0.22-10.mga7
+ Revision: 1347147
- add gentoo patch to fix build with exiv2 >= 0.27
+ luigiwalser <luigiwalser>
- rebuild for exiv2

* Sun Sep 23 2018 umeabot <umeabot> 0.22-9.mga7
+ Revision: 1301502
- Mageia 7 Mass Rebuild

* Mon May 14 2018 tv <tv> 0.22-8.mga7
+ Revision: 1229408
- rebuild against new libcfitsio with fixed gimp
+ daviddavid <daviddavid>
- rebuild for new cfitsio 3.450

* Sun Sep 24 2017 daviddavid <daviddavid> 0.22-6.mga7
+ Revision: 1158833
- backports some fedora patches

* Tue Jun 20 2017 neoclust <neoclust> 0.22-5.mga6
+ Revision: 1108009
- Rebuild against new exiv2

* Tue Nov 22 2016 eatdirt <eatdirt> 0.22-4.mga6
+ Revision: 1068814
- Rebuild for new cfitsio

* Thu Mar 10 2016 eatdirt <eatdirt> 0.22-3.mga6
+ Revision: 988751
- Rebuild for new cfitsio

* Fri Jan 08 2016 luigiwalser <luigiwalser> 0.22-2.mga6
+ Revision: 920538
- rebuild for lensfun

* Fri Jan 01 2016 luigiwalser <luigiwalser> 0.22-1.mga6
+ Revision: 917631
- 0.22
- remove upstreamed patches

* Tue Aug 25 2015 tv <tv> 0.19.2-11.mga6
+ Revision: 869204
- rebuild for new libexiv2

* Wed May 13 2015 luigiwalser <luigiwalser> 0.19.2-10.mga5
+ Revision: 821969
- adapt patch from dcraw to fix CVE-2015-3885

* Wed Oct 15 2014 umeabot <umeabot> 0.19.2-9.mga5
+ Revision: 744178
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.19.2-8.mga5
+ Revision: 690023
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Thu Feb 27 2014 eatdirt <eatdirt> 0.19.2-7.mga5
+ Revision: 597694
- Rebuild for new cfitsio

* Mon Feb 10 2014 dams <dams> 0.19.2-6.mga5
+ Revision: 589018
- rebuild for new exiv2

* Thu Dec 26 2013 luigiwalser <luigiwalser> 0.19.2-5.mga4
+ Revision: 560820
- add patches from fedora to build against lcms2 and fix CVE-2013-1438

* Sat Oct 19 2013 umeabot <umeabot> 0.19.2-4.mga4
+ Revision: 530068
- Mageia 4 Mass Rebuild

* Tue Jul 16 2013 eatdirt <eatdirt> 0.19.2-3.mga4
+ Revision: 454957
- Rebuild for cfitsio 3.350

* Mon Jun 03 2013 tv <tv> 0.19.2-2.mga4
+ Revision: 436310
- rebuild for new libpng

* Sat May 25 2013 shlomif <shlomif> 0.19.2-1.mga4
+ Revision: 427425
- Retab and trailing space
- New version - 0.19.2

* Mon Jan 14 2013 umeabot <umeabot> 0.18-6.mga3
+ Revision: 385009
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 13 2013 alien <alien> 0.18-5.mga3
+ Revision: 373455
- Split off ufraw-batch in it's own subpackage
+ boklm <boklm>
- Update group: Graphics/Editors -> Graphics/Editors and Converters

* Sat Dec 08 2012 malo <malo> 0.18-4.mga3
+ Revision: 328913
- update RPM group

* Sun Dec 25 2011 fwang <fwang> 0.18-3.mga3
+ Revision: 187375
- rebuild for new libtiff

* Sun Oct 09 2011 fwang <fwang> 0.18-2.mga2
+ Revision: 153436
- rebuild for new exiv2

* Sat Feb 26 2011 pterjan <pterjan> 0.18-1.mga2
+ Revision: 60295
- Drop old stuff
- imported package ufraw


* Tue Feb 22 2011 Götz Waschk <waschk@mandriva.org> 0.18-1mdv2011.0
+ Revision: 639280
- update to new version 0.18

* Wed Dec 01 2010 Funda Wang <fwang@mandriva.org> 0.17-4mdv2011.0
+ Revision: 604409
- rebuild for new exiv2

* Sat Aug 21 2010 Funda Wang <fwang@mandriva.org> 0.17-3mdv2011.0
+ Revision: 571620
- rebuild for new cfitsio

* Tue Aug 03 2010 Funda Wang <fwang@mandriva.org> 0.17-2mdv2011.0
+ Revision: 565566
- rebuild for new exiv2

* Fri Apr 02 2010 Frederic Crozat <fcrozat@mandriva.com> 0.17-1mdv2010.1
+ Revision: 530776
- Release 0.17
- Remove patch1 (merged upstream)

* Sun Jan 10 2010 Oden Eriksson <oeriksson@mandriva.com> 0.16-3mdv2010.1
+ Revision: 488806
- rebuilt against libjpeg v8

* Wed Dec 30 2009 Frederik Himpe <fhimpe@mandriva.org> 0.16-2mdv2010.1
+ Revision: 484192
- Rebuild for new libexiv2

* Fri Oct 16 2009 Frederic Crozat <fcrozat@mandriva.com> 0.16-1mdv2010.0
+ Revision: 457831
- Release 0.16
- Remove patch2 (merged upstream)
- Update patch1 (partially merged)

* Sun Aug 16 2009 Oden Eriksson <oeriksson@mandriva.com> 0.15-2mdv2010.0
+ Revision: 416859
- P2: fix build with gcc-4.4 (fedora)
- rebuilt against libjpeg v7

* Wed Dec 24 2008 Frederic Crozat <fcrozat@mandriva.com> 0.15-1mdv2009.1
+ Revision: 318385
- Release 0.15
- Build with OpenMP (multi-core) support

  + Oden Eriksson <oeriksson@mandriva.com>
    - lowercase ImageMagick

* Sun Oct 19 2008 Frederic Crozat <fcrozat@mandriva.com> 0.14.1-1mdv2009.1
+ Revision: 295409
- Release 0.14.1

* Thu Oct 16 2008 Funda Wang <fwang@mandriva.org> 0.14-1mdv2009.1
+ Revision: 294230
- BR cfitsio
- New version 0.14
- there is no use shipping two .desktop files

* Mon Sep 08 2008 Funda Wang <fwang@mandriva.org> 0.13-5mdv2009.0
+ Revision: 282456
- rebuild

* Wed Jun 18 2008 Thierry Vignaud <tv@mandriva.org> 0.13-4mdv2009.0
+ Revision: 225896
- rebuild
- fix spacing at top of description
- fix description

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Sat Dec 29 2007 Frederic Crozat <fcrozat@mandriva.com> 0.13-3mdv2008.1
+ Revision: 139175
- Patch0 (CVS): various CVS fixes :fix integer overflow in Canon exposure, additional WB settings, fix incandescent 400D WB, fix window resizing

  + Thierry Vignaud <tv@mandriva.org>
    - auto-convert XDG menu entry
    - kill re-definition of %%buildroot on Pixel's request

* Mon Nov 26 2007 Nicolas Lécureuil <nlecureuil@mandriva.com> 0.13-2mdv2008.1
+ Revision: 112022
- Rebuild for new exiv2

* Tue Nov 13 2007 Frederic Crozat <fcrozat@mandriva.com> 0.13-1mdv2008.1
+ Revision: 108434
- Release 0.13

* Mon Sep 24 2007 Frederic Crozat <fcrozat@mandriva.com> 0.12.1-2mdv2008.0
+ Revision: 92579
- Fix build (icon extension)

* Thu Aug 16 2007 Funda Wang <fwang@mandriva.org> 0.12.1-1mdv2008.0
+ Revision: 64262
- liblcms has renamed to lcms

  + Frederic Crozat <fcrozat@mandriva.com>
    - Release 0.12.1

* Wed Aug 01 2007 Frederic Crozat <fcrozat@mandriva.com> 0.12-2mdv2008.0
+ Revision: 57557
- Fix cinepaint plugin path
- build with gtkimageview support for 2008.0 and later

* Tue Jul 31 2007 Frederic Crozat <fcrozat@mandriva.com> 0.12-1mdv2008.0
+ Revision: 56889
- Release 0.12
- add conditional build for cinepaint plugin (disabled)
- clean buildrequires

* Fri Apr 20 2007 Angelo Naselli <anaselli@mandriva.org> 0.11-2mdv2008.0
+ Revision: 16411
- rebuilt against exiv2 0.14


* Wed Mar 07 2007 Frederic Crozat <fcrozat@mandriva.com> 0.11-1mdv2007.0
+ Revision: 134331
- Release 0.11

* Sun Mar 04 2007 Angelo Naselli <anaselli@mandriva.org> 0.10-5mdv2007.1
+ Revision: 132337
- rebuilt for new libexiv2

* Fri Mar 02 2007 Frederic Crozat <fcrozat@mandriva.com> 0.10-4mdv2007.1
+ Revision: 131484
- Don't package mimetype file, it is merged in shared-mime-info now

* Thu Mar 01 2007 Frederic Crozat <fcrozat@mandriva.com> 0.10-3mdv2007.1
+ Revision: 130674
-Clean specfile
-enable mimetype and gconf schema building
-fix Buildrequires
-install thumbnailer for gnome
-fix .desktop
-fix icon generation

* Tue Dec 05 2006 Pascal Terjan <pterjan@mandriva.org> 0.10-2mdv2007.1
+ Revision: 90781
- Enable debug
- always create XDG menu
- fix categories

* Mon Nov 27 2006 Pascal Terjan <pterjan@mandriva.org> 0.10-1mdv2007.1
+ Revision: 87349
- 0.10
- Import ufraw

* Wed Aug 09 2006 Till Kamppeter <till@mandriva.com> 0.9-1mdv2007.0
- Updated to version 0.9 final.
- Added XDG menu stuff.

* Wed May 10 2006 Lenny Cartier <lenny@mandriva.com> 0.8-1mdk
- Updated to version 0.8 final.

* Tue Mar 07 2006 Till Kamppeter <till@mandriva.com> 0.7-1mdk
- Updated to version 0.7 final.

* Fri Feb 03 2006 Till Kamppeter <till@mandriva.com> 0.7-0.1mdk
- Updated to the state of the CVS of 03/02/2006 (based on dcraw 8.03).
- Introduced %%mkrel.

* Wed Nov 16 2005 Till Kamppeter <till@mandriva.com> 0.6-1mdk
- Updated to version 0.6 final.

* Tue Oct 04 2005 Till Kamppeter <till@mandriva.com> 0.6-0.1mdk
- Updated to the state of the CVS of 03/10/2005 (0.6 generation of
  UFRaw).

* Fri Sep 16 2005 Till Kamppeter <till@mandriva.com> 0.5-0.4mdk
- Do the update really.
- Added man page.

* Thu Sep 15 2005 Till Kamppeter <till@mandriva.com> 0.5-0.3mdk
- Updated to the state of the CVS of 14/09/2005 (Fix for Sigma SD9 and
  SD10 DSLRs, bug 18552).

* Mon Aug 15 2005 Till Kamppeter <till@mandriva.com> 0.5-0.2mdk
- Updated to the state of the CVS of 14/08/2005 (underlying dcraw updated
  to 7.49, now new cameras like Minolta Alpha/Dynax/Maxxum 5D supported).

* Thu Aug 04 2005 Till Kamppeter <till@mandriva.com> 0.5-0.1mdk
- Updated to the state of the CVS of 03/08/2005 (dcraw 7.x intergrated).

* Mon Mar 07 2005 Till Kamppeter <till@mandrakesoft.com> 0.4-2mdk
- Added standalone version.

* Mon Mar 07 2005 Till Kamppeter <till@mandrakesoft.com> 0.4-1mdk
- Updated to version 0.4.
- New URL.
- Added "Requires: gimp".

* Mon Nov 08 2004 Till Kamppeter <till@mandrakesoft.com> 0.2-1mdk
- First release for Mandrakelinux

